import platform
from pathlib import Path

from pl_run_program.run_simple_program import run_simple_program

from pl_ci_cd._constants import UV_PROGRAM

UvProjectPath = Path


def initialize_uv_project(project_path: Path) -> UvProjectPath:
    """Initialize a bare, offline uv project at `project_path` using the configured uv binary."""
    args: list[str] = [
        "init",
        "--offline",
        "--bare",
        str(project_path),
        "--python",
        platform.python_version(),
    ]

    run_simple_program(UV_PROGRAM, args)

    return UvProjectPath(project_path)



from ._set_up import (
    set_up_check,
    set_up_formatter,
    set_up_lint,
    set_up_run_unit_tests_and_coverage,
    set_up_type_check,
)

__all__ = [
    "set_up_check",
    "set_up_formatter",
    "set_up_lint",
    "set_up_run_unit_tests_and_coverage",
    "set_up_type_check",
]



from pl_ci_cd._check import check
from pl_ci_cd._check_format import FormatCheckError, check_format
from pl_ci_cd._check_types import TypeCheckError, check_types
from pl_ci_cd._lint import LintError, lint
from pl_ci_cd._run_unit_tests_and_coverage import (
    CoverageOrTestsError,
    run_unit_tests_and_coverage,
)

__all__ = [
    "CoverageOrTestsError",
    "FormatCheckError",
    "LintError",
    "TypeCheckError",
    "check",
    "check_format",
    "check_types",
    "lint",
    "run_unit_tests_and_coverage",
]
